import "../stylesheets/RegisterAndLogin.css";
import {FormEvent, useState} from "react";
import {setCookie} from "../jwt/Cookies.ts";
import { useNavigate } from 'react-router-dom';
import { jwtDecode } from 'jwt-decode';


function Register() {
    const navigate = useNavigate();

    const [firstname, setFirstname] = useState('');
    const [lastname, setLastname] = useState('');
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');

    const isValidEmail = (email: string): boolean => {
        const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return emailRegex.test(email);
    };

    const isValidName = (name: string): boolean => {
        return name.trim() !== ''; // Prüfe, ob der Name nicht leer ist
    };

    const isValidPassword = (password: string): boolean => {
        return password.length >= 4; // Prüfe, ob das Passwort mindestens 4 Zeichen lang ist
    };

    const handleSubmit = async (e: FormEvent<HTMLFormElement>) => {
        e.preventDefault(); //verhindert, dass die Seite neu geladen wird, wenn das Formular abgeschickt wird

        if (!isValidEmail(email)) {
            window.alert('Ungültige E-Mail-Adresse.');
            return;
        }

        if (!isValidName(firstname)) {
            window.alert('Vorname darf nicht leer sein.');
            return;
        }

        if (!isValidName(lastname)) {
            window.alert('Nachname darf nicht leer sein.');
            return;
        }

        if (!isValidPassword(password)) {
            window.alert('Das Passwort muss mindestens 4 Zeichen lang sein.');
            return;
        }
        await handleRegister();
    };

    const handleRegister = async () => {
        try {
            const requestBody = {
                firstname: firstname,
                lastname: lastname,
                email: email,
                password: password
            };
            console.log(requestBody)
            const res = await fetch("http://localhost:8080/api/v1/auth/register", {
                    method: "POST",
                    headers: {
                        "Content-Type": "application/json"
                    },
                    body: JSON.stringify(requestBody)
                }
            )
            console.log(res);
            if (res.status === 200) {
                const {token} = await res.json();
                console.log("Jwt Token not decoded" + token);
                const decodedToken = jwtDecode(token);
                // @ts-ignore
                const expirationDate = new Date(decodedToken.exp * 1000); //*1000 Anzahl der Sekunden seit 1.1.1970 darstellt - JS arbeitet jedoch normalerweise mit Millisekunden
                setCookie("Jwt", token, expirationDate);
                console.log("Jwt decoded " + decodedToken);
                navigate('/');
            } else {
                // @ts-ignore
                const reader = res.body.getReader();
                const { value, done } = await reader.read();

                if (!done) {
                    const text = new TextDecoder().decode(value);
                    window.alert(text)
                    console.error(text);
                }
            }


        } catch (e: any) {
            window.alert(e.status);
        }
    };

    return (
        <main>
            <div className="register">
                <h2 className="h2">REGISTRIERUNG</h2>
                <form onSubmit={handleSubmit}>
                    <div className="form-group">
                        <input className="input"
                            type="text"
                            value={firstname}
                            onChange={(e) => setFirstname(e.target.value)}
                            placeholder="Name"
                        />
                    </div>
                    <div className="form-group">
                        <input className="input"
                            type="text"
                            value={lastname}
                            onChange={(e) => setLastname(e.target.value)}
                            placeholder="Nachname"
                        />
                    </div>
                    <div className="form-group">
                            <input className="input"
                                type="text"
                                value={email}
                                onChange={(e) => setEmail(e.target.value)}
                                placeholder="Mailadresse"
                            />
                    </div>
                    <div className="form-group">
                        <input className="input"
                            type="password"
                            value={password}
                            onChange={(e) => setPassword(e.target.value)}
                            placeholder="Passwort (mindestens 4 Zeichen)"
                        />
                    </div>
                    <div>
                            <button className="submitButton" type="submit">Anmelden</button>
                    </div>
                </form>
            </div>
        </main>
    );
}

export default Register;